==> cleanarch_dart-1.0.6.tar.gz: lib/src/cleanarch_base.dart <==
import 'dart:developer';
import 'dart:io';

import 'package:cleanarch_dart/src/usecases/get-config-model.usecase.dart';
import 'package:path/path.dart' as path;

import 'models/config-object.model.dart';
import 'usecases/generate-class.dart';
import 'usecases/generate-user-based-specific-schema.dart';
import 'usecases/get-selected-schemas.dart';
import 'usecases/parse-cli-input.dart';
import 'usecases/read-json-and-convert.dart';

void main(List<String> args) async {
  final executionLocal = path.normalize(Directory.current.absolute.path);
  print(['execute on: ', executionLocal]);
  final configModel = await GetConfigModelUsecase(
    executionLocal,
  );

  final userOpts = await ParseCliInput.parse(args);
  final keys = userOpts.keys.toSet();
  final allSchemas = configModel.schemas;
  final allCommands = configModel.commands;

  if (userOpts['all'] != null) {
    final classesBaseName = userOpts['all'] as List<String>;

    for (var classBaseName in classesBaseName) {
      for (var schema in allSchemas) {
        final result = await GenerateBasedSpecificSchema(
          key: schema.sufix,
          opts: userOpts,
          schema: schema,
          executionLocal: executionLocal,
          generateClassUtil: GenerateClass(''),
          classBaseName: classBaseName,
          isAbstract: schema.abstractClass,
        ).call();

        print(['SUCESS', result.folderName, result.fileName]);
      }
    }
  } else {
    final selectedShemaData = GetSelectedSchema(
      keys: userOpts.keys.toSet(),
      schemas: allSchemas,
      commands: allCommands,
    ).call();

    final schema = selectedShemaData.schema;
    final selectedSchemaKey = selectedShemaData.key;
    final elementKey = selectedShemaData.key;
    final classesBaseNames = (userOpts[elementKey]);

    assert(classesBaseNames != null);
    for (var classBaseName in classesBaseNames!) {
      final result = await GenerateBasedSpecificSchema(
        key: selectedShemaData.schema.sufix,
        opts: userOpts,
        schema: selectedShemaData.schema,
        executionLocal: executionLocal,
        generateClassUtil: GenerateClass(''),
        classBaseName: classBaseName,
        isAbstract: selectedShemaData.schema.abstractClass,
      ).call();
      print(['SUCESS', result.folderName, result.fileName]);
    }
  }
}

==> cleanarch_dart-1.0.7.tar.gz: lib/src/cleanarch_base.dart <==

import 'package:cleanarch_dart/src/usecases/get-config-model.usecase.dart';


import 'models/config-object.model.dart';
import 'usecases/generate-class.dart';
import 'usecases/generate-user-based-specific-schema.dart';
import 'usecases/get-selected-schemas.dart';
import 'usecases/parse-cli-input.dart';
import 'usecases/read-json-and-convert.dart';

void main(List<String> args, String executionLocal) async {
  
  print(['execute on: ', executionLocal]);
  final configModel = await GetConfigModelUsecase(
    executionLocal,
  );

  final userOpts = await ParseCliInput.parse(args);
  final keys = userOpts.keys.toSet();
  final allSchemas = configModel.schemas;
  final allCommands = configModel.commands;

  if (userOpts['all'] != null) {
    final classesBaseName = userOpts['all'] as List<String>;

    for (var classBaseName in classesBaseName) {
      for (var schema in allSchemas) {
        final result = await GenerateBasedSpecificSchema(
          key: schema.sufix,
          opts: userOpts,
          schema: schema,
          executionLocal: executionLocal,
          generateClassUtil: GenerateClass(''),
          classBaseName: classBaseName,
          isAbstract: schema.abstractClass,
        ).call();

        print(['SUCESS', result.folderName, result.fileName]);
      }
    }
  } else {
    final selectedShemaData = GetSelectedSchema(
      keys: userOpts.keys.toSet(),
      schemas: allSchemas,
      commands: allCommands,
    ).call();

    final schema = selectedShemaData.schema;
    final selectedSchemaKey = selectedShemaData.key;
    final elementKey = selectedShemaData.key;
    final classesBaseNames = (userOpts[elementKey]);

    assert(classesBaseNames != null);
    for (var classBaseName in classesBaseNames!) {
      final result = await GenerateBasedSpecificSchema(
        key: selectedShemaData.schema.sufix,
        opts: userOpts,
        schema: selectedShemaData.schema,
        executionLocal: executionLocal,
        generateClassUtil: GenerateClass(''),
        classBaseName: classBaseName,
        isAbstract: selectedShemaData.schema.abstractClass,
      ).call();
      print(['SUCESS', result.folderName, result.fileName]);
    }
  }
}
